@@ -1,4 +1,11 @@
+import cooper_util
+logger = cooper_util.logger
+
 from sinaspider.helper import get_config
 from sinaspider.weibo import Weibo
 from sinaspider.user import User, Owner
 from sinaspider.user_config import UserConfig
+from sinaspider.meta import Artist
+
+
+
