@@ -44,7 +44,6 @@ class UserConfig(OrderedDict):
             self['weibo_fetch'] = value
         is_fetch = self.setdefault('weibo_fetch', False)
         self.update_table()
-        logger.info(f'Fetch Weibo: {is_fetch}')
         return is_fetch
 
     def toggle_retweet_fetch(self, value=None):
@@ -53,7 +52,6 @@ class UserConfig(OrderedDict):
             self['retweet_fetch'] = value
         is_fetch = self.setdefault('retweet_fetch', False)
         self.update_table()
-        logger.info(f'Fetch Retweet: {is_fetch}')
         return is_fetch
 
     def toggle_media_download(self, value=None):
@@ -62,7 +60,6 @@ class UserConfig(OrderedDict):
             self['media_download'] = value
         is_download = self.setdefault('media_download', False)
         self.update_table()
-        logger.info(f'Download Media: {is_download}')
         return is_download
 
     def toggle_relation_fetch(self, value=None):
@@ -71,7 +68,6 @@ class UserConfig(OrderedDict):
             self['relation_fetch'] = value
         is_fetch = self.setdefault('relation_fetch', False)
         self.update_table()
-        logger.info(f'Fetch Relation: {is_fetch}')
         return is_fetch
 
     def toggle_all(self, value):
@@ -93,11 +89,8 @@ class UserConfig(OrderedDict):
                 return
         user = User(self['id'])
         if self.toggle_media_download():
-            if download_dir:
-                download_dir = Path(download_dir) / self['screen_name']
-            else:
-                download_dir = Path.home() / 'Downloads/sinaspider' / \
-                    self['screen_name']
+            download_dir = Path(download_dir or get_config()['download_dir'])
+            download_dir /= self['screen_name']
         else:
             download_dir = None
 
@@ -127,19 +120,6 @@ class UserConfig(OrderedDict):
         user.relation()
         logger.success(f'{self["screen_name"]} 的关注已获取')
 
-    @classmethod
-    def yield_config_user(cls, **params):
-        """
-        :param params:
-            传递给table.find的参数, 例如:
-                downloading=True,
-                order_by='weibo_since',
-                weibo_since={'lt': pendulum.now().subtract(days=days)}
-        :return:
-        """
-        for user in cls.table.find(**params):
-            yield cls(user)
-
     def __str__(self):
         text = ''
         for k, v in self.items():
@@ -148,15 +128,3 @@ class UserConfig(OrderedDict):
                 v = v.strftime('%Y-%m-%d %H:%M:%S')
             text += f'{k}: {v}\n'
         return text
-
-
-def _relation_complete():
-    for user in User.relation_table.find():
-        offline = True
-        text = ['清华', 'PKU', 'THU', '大学']
-        if desc := user.get('description'):
-            if any(t in desc for t in text):
-                offline = False
-        user_complete = User.from_user_id(user['id'], offline=offline)
-        user |= user_complete or {}
-        User.relation_table.update(user, ['id'])
